=======
Cameras
=======

Bispectral
----------
.. automodule:: crappy.camera.bispectral
   :members:

Meta Camera
-----------
.. automodule:: crappy.camera.camera
   :members:

Camera GStreamer
----------------
.. automodule:: crappy.camera.gstreamer
   :members:

Camera OpenCV
-------------
.. automodule:: crappy.camera.opencv
   :members:

Camera link
-----------
.. automodule:: crappy.camera.cameralink
   :members:

Fake Camera
-----------
.. automodule:: crappy.camera.fakeCamera
   :members:

File Reader
-----------
.. automodule:: crappy.camera.file_reader
   :members:

JAI
---
.. automodule:: crappy.camera.jai
   :members:

PiCamera
--------
.. automodule:: crappy.camera.pi_camera
   :members:

Seek Thermal Pro
----------------
.. automodule:: crappy.camera.seek_thermal_pro
   :members:

Webcam
------
.. automodule:: crappy.camera.webcam
   :members:

Xi API
------
.. automodule:: crappy.camera.xiapi
   :members:
